/****************************************************************************
** Meta object code from reading C++ file 'k3bverificationjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../k3b-26.04.3/libk3b/jobs/k3bverificationjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bverificationjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3K3b15VerificationJobE_t {};
} // unnamed namespace

template <> constexpr inline auto K3b::VerificationJob::qt_create_metaobjectdata<qt_meta_tag_ZN3K3b15VerificationJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3b::VerificationJob",
        "start",
        "",
        "cancel",
        "setDevice",
        "Device::Device*",
        "dev",
        "clear",
        "addTrack",
        "tracknum",
        "checksum",
        "Msf",
        "length",
        "setGrownSessionSize",
        "slotMediaLoaded",
        "slotDiskInfoReady",
        "K3b::Device::DeviceHandler*",
        "dh",
        "readTrack",
        "slotReaderProgress",
        "p",
        "slotReaderFinished",
        "success"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDevice'
        QtMocHelpers::SlotData<void(Device::Device *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addTrack'
        QtMocHelpers::SlotData<void(int, const QByteArray &, const Msf &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::QByteArray, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'addTrack'
        QtMocHelpers::SlotData<void(int, const QByteArray &)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::QByteArray, 10 },
        }}),
        // Slot 'setGrownSessionSize'
        QtMocHelpers::SlotData<void(const Msf &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotMediaLoaded'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDiskInfoReady'
        QtMocHelpers::SlotData<void(K3b::Device::DeviceHandler *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'readTrack'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReaderProgress'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'slotReaderFinished'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VerificationJob, qt_meta_tag_ZN3K3b15VerificationJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3b::VerificationJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b15VerificationJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b15VerificationJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3K3b15VerificationJobE_t>.metaTypes,
    nullptr
} };

void K3b::VerificationJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VerificationJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->start(); break;
        case 1: _t->cancel(); break;
        case 2: _t->setDevice((*reinterpret_cast<std::add_pointer_t<Device::Device*>>(_a[1]))); break;
        case 3: _t->clear(); break;
        case 4: _t->addTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Msf>>(_a[3]))); break;
        case 5: _t->addTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 6: _t->setGrownSessionSize((*reinterpret_cast<std::add_pointer_t<Msf>>(_a[1]))); break;
        case 7: _t->slotMediaLoaded(); break;
        case 8: _t->slotDiskInfoReady((*reinterpret_cast<std::add_pointer_t<K3b::Device::DeviceHandler*>>(_a[1]))); break;
        case 9: _t->readTrack(); break;
        case 10: _t->slotReaderProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->slotReaderFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *K3b::VerificationJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3b::VerificationJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b15VerificationJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int K3b::VerificationJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
